@@ -1,7 +1,8 @@
 #' Activate and deactivate development mode.
 #'
 #' When activated, \code{dev_mode} creates a new library for storing installed
-#' packages. This is automatically removed when \code{dev_mode} is activated.
+#' packages. This new library is automatically created when \code{dev_mode} is 
+#' activated if it does not already exist.
 #' This allows you to test development packages in a sandbox, without
 #' interfering with the other packages you have installed.
 #'
@@ -11,19 +12,27 @@
 #' @param path directory to for library.
 #' @export
 #' @examples
+#' \donttest{
 #' dev_mode()
 #' dev_mode()
+#' }
 dev_mode <- function(on = NULL, path = "~/R-dev") {
   lib_paths <- .libPaths()
 
-  path <- normalizePath(path, mustWork = FALSE)
+  path <- normalizePath(path, winslash = "/", mustWork = FALSE)
   if (is.null(on)) {
     on <- !(path %in% lib_paths)
   }
 
   if (on) {
+    if (!file.exists(path)) {
+      dir.create(path, recursive = TRUE, showWarnings = FALSE)
+    }
+    if (!file.exists(path)) {
+      stop("Failed to create ", path, call. = FALSE)
+    }
+
     message("Dev mode: ON")
-    dir.create(path, showWarnings = FALSE)
     .libPaths(c(path, lib_paths))
   } else {
     message("Dev mode: OFF")
